@@ -3,9 +3,13 @@ from typing import List, Dict
 from importlib import import_module
 from ai_kit.core.llms.client import Client
 import logging
+from dotenv import load_dotenv
+
+load_dotenv()
 
 logger = logging.getLogger(__name__)
 
+
 class ClientFactory:
     clients = {
         "together": {
@@ -18,7 +22,10 @@ class ClientFactory:
         },
         "groq": {
             "client": "ai_kit.core.llms.groq_client.GroqClient",
-            "supported_models": {"r1-70b": "deepseek-r1-distill-llama-70b"},
+            "supported_models": {
+                "r1-70b": "deepseek-r1-distill-llama-70b",
+                "qwq-32b": "qwen-qwq-32b"
+            },
             "api_key": {
                 "name": "GROQ_API_KEY",
                 "url": "https://console.groq.com/keys",
@@ -54,7 +61,8 @@ class ClientFactory:
                 "r1": "deepseek/deepseek-r1",
                 "r1-70b": "deepseek/deepseek-r1-distill-llama-70b",
                 "gemini-2.0-flash": "google/gemini-2.0-flash-001",
-                "claude-3.7-sonnet": "anthropic/claude-3.7-sonnet"
+                "claude-3.7-sonnet": "anthropic/claude-3.7-sonnet",
+                "qwq-32b": "qwen/qwq-32b"
             },
             "api_key": {
                 "name": "OPENROUTER_API_KEY",
@@ -81,18 +89,31 @@ class ClientFactory:
                 "url": client["api_key"]["url"],
                 "key": os.getenv(client["api_key"]["name"]),
             }
-            for client in ClientFactory.clients.values() 
-            if os.getenv(client["api_key"]["name"])
+            for client in ClientFactory.clients.values()
+        ]
+
+    @staticmethod
+    def get_supported_models() -> List[str]:
+        return [
+            model
+            for client in ClientFactory.clients.values()
+            for model in client["supported_models"]
         ]
 
     @staticmethod
     def get_client_by_model(model: str) -> Client:
         # Gather all clients that support the specified model.
         supported_clients = [
-            client for client in ClientFactory.clients.values()
+            client
+            for client in ClientFactory.clients.values()
             if model in client["supported_models"]
         ]
 
+        if len(supported_clients) == 0:
+            raise ValueError(
+                f"No supported clients found for model: {model}. Valid models are: {ClientFactory.get_supported_models()}"
+            )
+
         # Select the first client that also has a valid API key.
         for client in supported_clients:
             api_key = os.getenv(client["api_key"]["name"])
